package com.sooka.system.service.impl;

import java.util.List;

import com.sooka.common.annotation.DataSource;
import com.sooka.common.core.text.Convert;
import com.sooka.common.enums.DataSourceType;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.sooka.system.mapper.TgjjBsxxMapper;
import com.sooka.system.domain.TgjjBsxx;
import com.sooka.system.service.ITgjjBsxxService;

/**
 * 报税信息Service业务层处理
 *
 * @author lei
 * @date 2021-11-16
 */
@Service

public class TgjjBsxxServiceImpl extends Guiji_Base_Service implements ITgjjBsxxService {
    @Autowired
    private TgjjBsxxMapper tgjjBsxxMapper;

    /**
     * 查询报税信息
     *
     * @param ID 报税信息ID
     * @return 报税信息
     */
    @Override
    public TgjjBsxx selectTgjjBsxxById(Long ID) {
        return tgjjBsxxMapper.selectTgjjBsxxById(ID);
    }

    /**
     * 查询报税信息列表
     *
     * @param tgjjBsxx 报税信息
     * @return 报税信息
     */
    @Override
    public List<TgjjBsxx> selectTgjjBsxxList(TgjjBsxx tgjjBsxx) {
        List ls = tgjjBsxxMapper.selectTgjjBsxxList(tgjjBsxx);
        tgjjBsxx .setInterfaceinfoId("c7d73e8a-4f1d-4d83-bccd-a22e6247119b");
        tgjjBsxx.setInterfaceinfoName("共享-市公积金-报税信息");
        tgjjBsxx.setInterfacetype("platform_interfacetype_1");
        add_log(tgjjBsxx);
        return ls;
    }

    /**
     * 新增报税信息
     *
     * @param tgjjBsxx 报税信息
     * @return 结果
     */
    @Override
    public int insertTgjjBsxx(TgjjBsxx tgjjBsxx) {
        return tgjjBsxxMapper.insertTgjjBsxx(tgjjBsxx);
    }

    /**
     * 修改报税信息
     *
     * @param tgjjBsxx 报税信息
     * @return 结果
     */
    @Override
    public int updateTgjjBsxx(TgjjBsxx tgjjBsxx) {
        return tgjjBsxxMapper.updateTgjjBsxx(tgjjBsxx);
    }

    /**
     * 删除报税信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTgjjBsxxByIds(String ids) {
        return tgjjBsxxMapper.deleteTgjjBsxxByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除报税信息信息
     *
     * @param ID 报税信息ID
     * @return 结果
     */
    @Override
    public int deleteTgjjBsxxById(Long ID) {
        return tgjjBsxxMapper.deleteTgjjBsxxById(ID);
    }
}
